/// <reference types="node" />
import * as AWS from 'aws-sdk';
import { ILogger } from 'typescript-ilogger';
import { BaseClass } from 'typescript-helper-functions';
import { IS3Helper } from './interface';
import { SignedUrlType } from './signed-url-type';
/**
 * S3 Helper
 */
export declare class S3Helper extends BaseClass implements IS3Helper {
    /**
     * AWS Repository for S3
     */
    Repository: AWS.S3;
    /**
     * Create new instance of S3Helper
     * @param logger {ILogger} Logger
     * @param repository {AWS.S3} A new repository will be created if not supplied
     * @param options {AWS.S3.ClientConfiguration} Only needed if a repository is supplied
     */
    constructor(logger: ILogger, repository?: AWS.S3, options?: AWS.S3.ClientConfiguration);
    CopyObjectAsync(sourceBucket: string, sourceKey: string, destinationBucket: string, destinationKey: string): Promise<AWS.S3.CopyObjectOutput>;
    CreateBucketAsync(name: string): Promise<AWS.S3.CreateBucketOutput>;
    DeleteBucketAsync(name: string): Promise<object>;
    DeleteObjectAsync(bucket: string, key: string): Promise<AWS.S3.DeleteObjectOutput>;
    DeleteObjectsAsync(bucket: string, keys: string[]): Promise<AWS.S3.DeleteObjectsOutput>;
    DeleteObjectTagsAsync(bucket: string, key: string): Promise<object>;
    GetBucketMetadataAsync(bucket: string): Promise<object>;
    GetObjectAsJsonAsync<T>(bucket: string, key: string): Promise<T>;
    GetObjectAsync(bucket: string, key: string): Promise<AWS.S3.GetObjectOutput>;
    GetObjectContentsAsync(bucket: string, key: string): Promise<Buffer | undefined>;
    GetObjectMetadataAsync(bucket: string, key: string): Promise<AWS.S3.Metadata | undefined>;
    GetObjectTagsAsync(bucket: string, key: string): Promise<AWS.S3.TagSet>;
    GetSignedUrl(bucket: string, key: string, type: SignedUrlType, timeoutInMinutes?: number, acl?: AWS.S3.ObjectCannedACL): Promise<string>;
    MoveObjectAsync(sourceBucket: string, sourceKey: string, destinationBucket: string, destinationKey: string): Promise<void>;
    MultipartUploadCompleteAsync(bucket: string, key: string, uploadId: string): Promise<AWS.S3.CompleteMultipartUploadOutput>;
    MultipartUploadStartAsync(bucket: string, key: string, acl?: AWS.S3.ObjectCannedACL): Promise<AWS.S3.CreateMultipartUploadOutput>;
    MultipartUploadUploadPartAsync(bucket: string, key: string, uploadId: string, uploadPart: number, contents: string): Promise<AWS.S3.UploadPartOutput>;
    PutObjectAsync(bucket: string, key: string, contents: string | Buffer, acl?: AWS.S3.ObjectCannedACL, encoding?: string): Promise<AWS.S3.PutObjectOutput>;
    SetObjectTagAsync(bucket: string, key: string, tagName: string, tagValue: string): Promise<AWS.S3.PutObjectTaggingOutput>;
    SetObjectTagsAsync(bucket: string, key: string, tags: AWS.S3.TagSet): Promise<AWS.S3.PutObjectTaggingOutput>;
}
